@@ -5,7 +5,7 @@ use vars qw($VERSION);
 use Carp;
 use Text::Wrap;
 use ExtUtils::Constant::Utils qw(C_stringify perl_stringify);
-$VERSION = '0.23_01';
+$VERSION = '0.23_03';
 
 use constant is_perl56 => ($] < 5.007 && $] > 5.005_50);
 
@@ -331,8 +331,8 @@ of C code to proceed and follow the assignment. I<pre> will be at the start
 of a block, so variables may be defined in it.
 
 =cut
-# Hmm. value undef to do NOTDEF? value () to do NOTFOUND?
 
+# Hmm. value undef to to NOTDEF? value () to do NOTFOUND?
 sub assign {
   my $self = shift;
   my $args = shift;
@@ -581,9 +581,9 @@ sub switch_clause {
     $body .= $indent . "case '" . C_stringify ($char) . "':\n";
     foreach my $thisone (sort {
 	# Deal with the case of an item actually being an array ref to 1 or 2
-	# hashrefs. Don't assign to $a or $b, as they're aliases to the original
-	my $l = ref $a eq 'ARRAY' ? ($a->[0] || $a->[1]) : $a;
-	my $r = ref $b eq 'ARRAY' ? ($b->[0] || $b->[1]) : $b;
+	# hashrefs. Don't assign to $a or $b, as they're aliases to the orignal
+	my $l = ref $a eq 'ARRAY' ? ($a->[0] || $->[1]) : $a;
+	my $r = ref $b eq 'ARRAY' ? ($b->[0] || $->[1]) : $b;
 	# Sort by weight first
 	($r->{weight} || 0) <=> ($l->{weight} || 0)
 	    # Sort equal weights by name
@@ -634,7 +634,7 @@ sub C_constant_other_params {
   '';
 }
 
-sub C_constant_other_params_defintion {
+sub C_constant_other_params_definition {
   '';
 }
 
@@ -926,7 +926,7 @@ sub C_constant {
   # Something like ", STRLEN len"
   $body .= ", " . $self->namelen_param_definition($params)
     unless defined $namelen;
-  $body .= $self->C_constant_other_params_defintion($params);
+  $body .= $self->C_constant_other_params_definition($params);
   $body .= ") {\n";
 
   if (defined $namelen) {
